==> react-atom-input-5.4.0.tgz: package/lib/Input/HOC/withIcons/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["leftIcon", "rightIcon", "onClickLeftIcon", "onClickRightIcon"];
import PropTypes from 'prop-types';
import cx from 'classnames';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var TYPES = {
  LEFT: 'left',
  RIGHT: 'right'
};
var BASE_CLASS = 'sui-AtomInput';
var CLASS_ICON = BASE_CLASS + "--withIcon";
var CLASS_ICON_LEFT = CLASS_ICON + "--" + TYPES.LEFT;
var CLASS_ICON_RIGHT = CLASS_ICON + "--" + TYPES.RIGHT;
var CLASS_ICON_COMPONENT = CLASS_ICON + "-icon";
var CLASS_ICON_COMPONENT_HANDLER = CLASS_ICON_COMPONENT + "--withHandler";
var CLASS_ICON_COMPONENT_LEFT = CLASS_ICON_COMPONENT + "--" + TYPES.LEFT;
var CLASS_ICON_COMPONENT_RIGHT = CLASS_ICON_COMPONENT + "--" + TYPES.RIGHT;

var withIcons = function withIcons(WrappedInput) {
  var Icon = function Icon(_ref) {
    var _cx, _cx2, _cx3;

    var leftIcon = _ref.leftIcon,
        rightIcon = _ref.rightIcon,
        onClickLeftIcon = _ref.onClickLeftIcon,
        onClickRightIcon = _ref.onClickRightIcon,
        props = _objectWithoutPropertiesLoose(_ref, _excluded);

    var handleLeftClick = function handleLeftClick(e) {
      onClickLeftIcon && onClickLeftIcon(e);
    };

    var handleRightClick = function handleRightClick(e) {
      onClickRightIcon && onClickRightIcon(e);
    };

    return leftIcon || rightIcon ? /*#__PURE__*/_jsxs("div", {
      className: cx(CLASS_ICON, (_cx = {}, _cx[CLASS_ICON_LEFT] = leftIcon, _cx[CLASS_ICON_RIGHT] = rightIcon, _cx)),
      children: [leftIcon && /*#__PURE__*/_jsx("span", {
        className: cx(CLASS_ICON_COMPONENT, CLASS_ICON_COMPONENT_LEFT, (_cx2 = {}, _cx2[CLASS_ICON_COMPONENT_HANDLER] = onClickLeftIcon, _cx2)),
        onClick: handleLeftClick,
        children: leftIcon
      }), /*#__PURE__*/_jsx(WrappedInput, _extends({}, props)), rightIcon && /*#__PURE__*/_jsx("span", {
        className: cx(CLASS_ICON_COMPONENT, CLASS_ICON_COMPONENT_RIGHT, (_cx3 = {}, _cx3[CLASS_ICON_COMPONENT_HANDLER] = onClickRightIcon, _cx3)),
        onClick: handleRightClick,
        children: rightIcon
      })]
    }) : /*#__PURE__*/_jsx(WrappedInput, _extends({}, props));
  };

  return Icon;
};

export default withIcons;

==> react-atom-input-5.5.0.tgz: package/lib/Input/HOC/withIcons/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["leftIcon", "rightIcon", "onClickLeftIcon", "onClickRightIcon"];
import PropTypes from 'prop-types';
import cx from 'classnames';
import { BASE_CLASS_ICON, BASE_CLASS_ICON_LEFT, BASE_CLASS_ICON_RIGHT, BASE_CLASS_ICON_COMPONENT, BASE_CLASS_ICON_COMPONENT_HANDLER, BASE_CLASS_ICON_COMPONENT_LEFT, BASE_CLASS_ICON_COMPONENT_RIGHT } from './config';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var withIcons = function withIcons(WrappedInput) {
  var Icon = function Icon(_ref) {
    var _cx, _cx2, _cx3;

    var leftIcon = _ref.leftIcon,
        rightIcon = _ref.rightIcon,
        onClickLeftIcon = _ref.onClickLeftIcon,
        onClickRightIcon = _ref.onClickRightIcon,
        props = _objectWithoutPropertiesLoose(_ref, _excluded);

    var handleLeftClick = function handleLeftClick(e) {
      onClickLeftIcon && onClickLeftIcon(e);
    };

    var handleRightClick = function handleRightClick(e) {
      onClickRightIcon && onClickRightIcon(e);
    };

    return leftIcon || rightIcon ? /*#__PURE__*/_jsxs("div", {
      className: cx(BASE_CLASS_ICON, (_cx = {}, _cx[BASE_CLASS_ICON_LEFT] = leftIcon, _cx[BASE_CLASS_ICON_RIGHT] = rightIcon, _cx)),
      children: [leftIcon && /*#__PURE__*/_jsx("span", {
        className: cx(BASE_CLASS_ICON_COMPONENT, BASE_CLASS_ICON_COMPONENT_LEFT, (_cx2 = {}, _cx2[BASE_CLASS_ICON_COMPONENT_HANDLER] = onClickLeftIcon, _cx2)),
        onClick: handleLeftClick,
        children: leftIcon
      }), /*#__PURE__*/_jsx(WrappedInput, _extends({}, props)), rightIcon && /*#__PURE__*/_jsx("span", {
        className: cx(BASE_CLASS_ICON_COMPONENT, BASE_CLASS_ICON_COMPONENT_RIGHT, (_cx3 = {}, _cx3[BASE_CLASS_ICON_COMPONENT_HANDLER] = onClickRightIcon, _cx3)),
        onClick: handleRightClick,
        children: rightIcon
      })]
    }) : /*#__PURE__*/_jsx(WrappedInput, _extends({}, props));
  };

  return Icon;
};

export default withIcons;
